This function replaces Umlauts, expands "str" to "strasse", transliterates all non-ascii characters, removes punctuation and converts to lower case.
sanitize_street(x)A character vector of the same length as x containing the sanitized street names.
A character vector containing the steet names
Daniel Schürmann
This is an internal function used in addrlink.
Make sure house numbers have already been extracted.
Use split_number or split_address for that.
Only steet names can go into sanitize_street.
split_address, split_number, addrlink